package SPVM::R::OP::AnyObject;



1;

=head1 Name

SPVM::R::OP::AnyObject - Short Description

=head1 Description

The R::OP::AnyObject class in L<SPVM> has methods to do someting.

=head1 Usage

  use R::OP::AnyObject;

=head1 Details



=head1 Inheritance



=head1 Interfaces



=head1 Enumerations



=head1 Fields



=head1 Class Methods



=head1 Instance Methods




=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2024 Yuki Kimoto

MIT License

