// Copyright (c) 2024 Yuki Kimoto
// MIT License

#include "spvm_native.h"

extern "C" {

static const char* FILE_NAME = "R/OP/Matrix/Long.cpp";

int32_t SPVM__R__OP__Matrix__Long__foo(SPVM_ENV* env, SPVM_VALUE* stack) {
  
  return 0;
}

}
